aboutsummaryrefslogtreecommitdiffstats
path: root/src/classes/com/sun/opengl/util/texture
diff options
context:
space:
mode:
authorSven Gothel <[email protected]>2008-07-03 14:59:12 +0000
committerSven Gothel <[email protected]>2008-07-03 14:59:12 +0000
commit21d712edbe269d5cf74718fea40734299470bdc2 (patch)
treed1426f34bee69c5460b74599f8d43185ade6db60 /src/classes/com/sun/opengl/util/texture
parent252efbfd61fb62883df028cba5743e458a5b18c7 (diff)
GL Unification 1st round.
Terminology: ARB Extensions: "GL2", "ARB", "OES", "OML" Vendor Extensions: "EXT", "NV", "ATI", "SGI", "SGIS", "SGIX", "HP", "IBM", "WIN" Pass-1 Unify ARB extensions with the same value Pass-2 Unify vendor extensions, if exist as an ARB extension with the same value. Pass-3 Emit TODO: - Break down GL.java enumerations: GL + GL2ES (for future GL3) - Same for function calls .. git-svn-id: file:///usr/local/projects/SUN/JOGL/git-svn/svn-server-sync/jogl/branches/JOGL_2_SANDBOX@1703 232f8b59-042b-4e1e-8c03-345bb8c30851
Diffstat (limited to 'src/classes/com/sun/opengl/util/texture')
-rwxr-xr-xsrc/classes/com/sun/opengl/util/texture/Texture.java14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/classes/com/sun/opengl/util/texture/Texture.java b/src/classes/com/sun/opengl/util/texture/Texture.java
index 56f7e8a6a..b1066f120 100755
--- a/src/classes/com/sun/opengl/util/texture/Texture.java
+++ b/src/classes/com/sun/opengl/util/texture/Texture.java
@@ -259,7 +259,7 @@ public class Texture {
*
* @return the OpenGL target of this texture
* @see javax.media.opengl.GL#GL_TEXTURE_2D
- * @see javax.media.opengl.GL2#GL_TEXTURE_RECTANGLE_ARB
+ * @see javax.media.opengl.GL2#GL_TEXTURE_RECTANGLE
*/
public int getTarget() {
return target;
@@ -350,7 +350,7 @@ public class Texture {
* @return the texture coordinates corresponding to the specified sub-image
*/
public TextureCoords getSubImageTexCoords(int x1, int y1, int x2, int y2) {
- if (target == GL2.GL_TEXTURE_RECTANGLE_ARB) {
+ if (target == GL2.GL_TEXTURE_RECTANGLE) {
if (mustFlipVertically) {
return new TextureCoords(x1, texHeight - y1, x2, texHeight - y2);
} else {
@@ -460,7 +460,7 @@ public class Texture {
texWidth = imgWidth;
texHeight = imgHeight;
- texTarget = GL2.GL_TEXTURE_RECTANGLE_ARB;
+ texTarget = GL2.GL_TEXTURE_RECTANGLE;
} else {
// If we receive non-power-of-two compressed texture data and
// don't have true hardware support for compressed textures, we
@@ -590,8 +590,8 @@ public class Texture {
int magFilter = GL.GL_LINEAR;
int wrapMode = (gl.isExtensionAvailable("GL_VERSION_1_2") || !gl.isGL2()) ? GL.GL_CLAMP_TO_EDGE : GL2.GL_CLAMP;
- // REMIND: figure out what to do for GL_TEXTURE_RECTANGLE_ARB
- if (texTarget != GL2.GL_TEXTURE_RECTANGLE_ARB) {
+ // REMIND: figure out what to do for GL_TEXTURE_RECTANGLE
+ if (texTarget != GL2.GL_TEXTURE_RECTANGLE) {
gl.glTexParameteri(texParamTarget, GL.GL_TEXTURE_MIN_FILTER, minFilter);
gl.glTexParameteri(texParamTarget, GL.GL_TEXTURE_MAG_FILTER, magFilter);
gl.glTexParameteri(texParamTarget, GL.GL_TEXTURE_WRAP_S, wrapMode);
@@ -605,7 +605,7 @@ public class Texture {
// map
if ((this.target == 0) ||
(this.target == GL.GL_TEXTURE_2D) ||
- (this.target == GL2.GL_TEXTURE_RECTANGLE_ARB)) {
+ (this.target == GL2.GL_TEXTURE_RECTANGLE)) {
this.target = texTarget;
}
@@ -852,7 +852,7 @@ public class Texture {
private void setImageSize(int width, int height, int target) {
imgWidth = width;
imgHeight = height;
- if (target == GL2.GL_TEXTURE_RECTANGLE_ARB) {
+ if (target == GL2.GL_TEXTURE_RECTANGLE) {
if (mustFlipVertically) {
coords = new TextureCoords(0, imgHeight, imgWidth, 0);
} else {